
Requirements Summary
====================

# DOI management

## The software shall be capable of accepting a request to create a draft DOI. ([#5](https://github.com/NASA-PDS/pds-doi-service/issues/5))


This requirement is not impacted by the current version
## The software shall be capable of accepting a request to reserve a DOI. ([#6](https://github.com/NASA-PDS/pds-doi-service/issues/6))


This requirement is not impacted by the current version
## The software shall be capable of accepting a request to release a DOI. ([#7](https://github.com/NASA-PDS/pds-doi-service/issues/7))


This requirement is not impacted by the current version
## The software shall be capable of accepting a request to deactivate a DOI. ([#8](https://github.com/NASA-PDS/pds-doi-service/issues/8))


This requirement is not impacted by the current version
## The software shall be capable of accepting a request to update DOI metadata. ([#9](https://github.com/NASA-PDS/pds-doi-service/issues/9))


This requirement is not impacted by the current version
## The software shall be capable of batch processing >1 DOI requests.	 ([#10](https://github.com/NASA-PDS/pds-doi-service/issues/10))


This requirement is not impacted by the current version
# DOI metadata

## The software shall be capable of autonomously generating the minimum set of DOI metadata from PDS4 Collection, Bundle, Document products. ([#11](https://github.com/NASA-PDS/pds-doi-service/issues/11))


This requirement is not impacted by the current version
## The software shall validate a minimum set of metadata is provided when reserving, releasing, or updating a DOI. This minimum set of metadata will be defined by the PDS DOI Working Group. ([#12](https://github.com/NASA-PDS/pds-doi-service/issues/12))


This requirement is not impacted by the current version
## The software shall validate the DOI metadata when reserving, releasing, or updating a DOI. ([#13](https://github.com/NASA-PDS/pds-doi-service/issues/13))


This requirement is not impacted by the current version
#  DOI interface support

## The software shall maintain a database of PDS DOIs and their current state. ([#14](https://github.com/NASA-PDS/pds-doi-service/issues/14))


This requirement is not impacted by the current version
## The software shall maintain the ability to manage DOIs through OSTI ([#15](https://github.com/NASA-PDS/pds-doi-service/issues/15))


This requirement is not impacted by the current version
## The software shall maintain the ability to manage DOIs through DataCite. ([#16](https://github.com/NASA-PDS/pds-doi-service/issues/16))


This requirement is not impacted by the current version
# DOI-management

## The software shall provide a Status capability that will allow a user to query for the current status of a DOI ([#30](https://github.com/NASA-PDS/pds-doi-service/issues/30))


This requirement is not impacted by the current version
## The software shall provide the capability of producing a DOI Status Report based upon a user-specified query ([#35](https://github.com/NASA-PDS/pds-doi-service/issues/35))


This requirement is not impacted by the current version
# default

## As a node operator, I want to include a DOI as a related identifier in the DOI metadata for parent PDS4 products. ([#69](https://github.com/NASA-PDS/pds-doi-service/issues/69))


This requirement is not impacted by the current version
## As a node user, I want the LIDVID associated with a DOI to be automatically updated for accumulating bundles / collections. ([#97](https://github.com/NASA-PDS/pds-doi-service/issues/97))


This requirement is not impacted by the current version
## As the PDS, I want to mint DOIs through DataCite ([#103](https://github.com/NASA-PDS/pds-doi-service/issues/103))


This requirement is not impacted by the current version
## Develop DOI Service - Registry integration component for accumulating bundles ([#111](https://github.com/NASA-PDS/pds-doi-service/issues/111))


This requirement is not impacted by the current version
## As an operator, I want to reserve a DOI through DataCite ([#171](https://github.com/NASA-PDS/pds-doi-service/issues/171))


This requirement is not impacted by the current version
## As an operator, I want query for one or more minted DOIs from DataCite ([#172](https://github.com/NASA-PDS/pds-doi-service/issues/172))


This requirement is not impacted by the current version
## As an operator, I want to query for a DOI's change history through DataCite ([#173](https://github.com/NASA-PDS/pds-doi-service/issues/173))


This requirement is not impacted by the current version
## As an operator, I want to release a DOI through DataCite ([#174](https://github.com/NASA-PDS/pds-doi-service/issues/174))


This requirement is not impacted by the current version
## As an operator, I want to update DOI metadata through DataCite ([#175](https://github.com/NASA-PDS/pds-doi-service/issues/175))


This requirement is not impacted by the current version
## As an API user, I want to have pagination that is consistent with the PDS API. ([#176](https://github.com/NASA-PDS/pds-doi-service/issues/176))


This requirement is not impacted by the current version
## As an API user I want to filter on lidvids with wildcards ([#177](https://github.com/NASA-PDS/pds-doi-service/issues/177))


This requirement is not impacted by the current version
## As an API user I want to filter on PDS3 Data Set IDs with wildcards ([#180](https://github.com/NASA-PDS/pds-doi-service/issues/180))


This requirement is not impacted by the current version
## As a user of the API, I want to see the DOI's title when I go GET /dois request ([#183](https://github.com/NASA-PDS/pds-doi-service/issues/183))


This requirement is not impacted by the current version
## As an API user, I want to always have an update date for the DOIs ([#184](https://github.com/NASA-PDS/pds-doi-service/issues/184))


This requirement is not impacted by the current version
